ColumnDef class

Constructors

ColumnDef({required String columnName, required ColumnTypes type, bool isPrimaryKey = false, bool isUnique = false, bool isAutoIncrement = false, bool isNotNull = true, String? defaultValue, ForeingkeyRef? foreingKey, AlterColumnType? alterColumnType, String? newColumnName})

Properties

alterColumnType AlterColumnType?
final
columnName String
final
defaultValue String?
final
foreingKey ForeingkeyRef?
final
hashCode int
The hash code for this object.
no setterinherited
isAutoIncrement bool
final
isNotNull bool
final
isPrimaryKey bool
final
isUnique bool
final
newColumnName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ColumnTypes
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited